# Bruinen Python SDK

Welcome to the Bruinen Python SDK! The SDK makes it easy for you to access the Bruinen API without having to interact with server code directly. 

The SDK provides three modules to help with accessing Bruinen's API:
- `client`: Wrapper around all API endpoints
- `confirm`: Module to enable user confirmation of actions at call time
- `langchain`: Set of out-of-the-box tools for use in Langchain [agents](https://python.langchain.com/en/latest/modules/agents.html)

To install the SDK, run `pip install bruinen`. For more details on how to use the SDK, visit the [docs](https://docs.bruinen.co).

If you have any questions, feel free to join our [Discord](https://discord.gg/4WwZa9TPgx) for access to the team.